@@ -1,5 +1,5 @@
-from classes.__init__ import getKarma
-from classes.__init__ import getRaw
+from classes.karma import getKarma
+from classes.raw import getRaw
 #from gets.karma import getKarmaCount
 #compare = getKarmaCount("RayhanADev")
 class Parser:
